/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 * Project  Zero
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */
 
 /**
  * This is a IBM WebSphere sMash Stub implementation of OpenAjax-mashup.js	
  * It defines OpenAjax.hubspi
 */
/* 
 * If hubspi is already defined we are a NOOP
*/
if(OpenAjax && typeof OpenAjax.hubspi == "undefined"){
/**
 *
 * hubspi for high level comm
 */
OpenAjax.hubspi = new (function() {
    function dbg (msg)
    {
    	if (console && console.debug && console.log) {
    		//console.debug(document.location.host + " : " + msg);
    	}
    }
    function inf (msg)
    {
    	if (console && console.info && console.log) {
    		//console.info(document.location.host + " : " + msg);
    	}
    }
	this.clnts = {};
	this.register = function(provider) { 
		inf("registering provider name:" + provider.getName() + " version:" + provider.getVersion());
		this.provider = provider;
		return true; 
	}
	this.registerClient = function(provider, clientName) { 
		inf("registering client:" + clientName + " by provider name:" + provider.getName() + " version:" + provider.getVersion());
		var clnt = {};
		clnt.clientName = clientName;
		clnt.sub = [];	
		clnt.topic = [];
		this.clnts[clientName] = clnt;
		return true;
	}
	/**
	 * 
	 */
	this.publishEvent = function(clientName, /*pass thru to provider */topic, data) {
		dbg("publishEvent:" + " clientName:" + clientName + " topic:" + topic + " data:" + data);
		for ( i in this.clnts) {		
			var clnt = this.clnts[i];
			if (clnt.clientName != clientName && (find(clnt.topic, topic)!= -1)) {
				// in the real hub there will be more here.
				this.provider.sendEvent (clnt.clientName, topic, data, clnt.sub);
			}
		}	
		return;
	}
	this.subscribeReq = function(clientName, topic, subId) {
		inf("subscribeReq:" + " clientName:" + clientName + " topic:" + topic + " subId:" + subId);
		var clnt = this.clnts[clientName];
		if (clnt) {
			clnt.sub.push (subId);	
			clnt.topic.push (topic);
		} else {
			dbg (clientName +" is not registered");
		}
		return true;
	}
	this.unsubscribeReq = function(clientName, subId) {
		dbg("unsubscribeReq:" + " clientName:" + clientName + " subId:" + subId);
		var clnt = this.clnts[clientName];
		if (clnt) {
			var idx = find (clnt.sub, subId);
			if (idx != -1) {
				clnt.sub.splice (idx,1);
				clnt.topic.splice (idx,1);
			}
		} else {
			dbg (clientName +" is not registered");
		}
		return true;
	}
	
	function find (/* Array */ arr, /* string */ val) 
	{
		var ret = false;
		var i = 0;
		while (i < arr.length)
		{
			if (arr[i] == val) {
				ret = true;
				return i;
			} else {
				i++;
			}
		}		
		return (-1);
	}
})();
}
